@@ -404,10 +404,12 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 	gchar *basename = NULL;
 	const gchar *output_name;
 	guint display;
+	guint target_whitepoint;
 
 	/* get shared data */
 	g_object_get (calibrate_argyll,
 		      "basename", &basename,
+		      "target-whitepoint", &target_whitepoint,
 		      NULL);
 
 	/* get correct name of the command */
@@ -447,6 +449,8 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 	g_ptr_array_add (array, g_strdup ("-v"));
 	g_ptr_array_add (array, g_strdup ("-ql"));
 	g_ptr_array_add (array, g_strdup ("-m"));
+	if (target_whitepoint > 0)
+		g_ptr_array_add (array, g_strdup_printf ("-t%i", target_whitepoint));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", display));
 	g_ptr_array_add (array, g_strdup_printf ("-y%c", kind));
 	g_ptr_array_add (array, g_strdup ("-P 0.5,0.5,1.2"));
@@ -802,14 +806,12 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	/* get shared data */
 	g_object_get (calibrate_argyll,
 		      "basename", &basename,
+		      "copyright", &copyright,
+		      "description", &description,
+		      "model", &model,
+		      "manufacturer", &manufacturer,
 		      NULL);
 
-	/* get profile text data */
-	copyright = gcm_calibrate_get_profile_copyright (GCM_CALIBRATE (calibrate_argyll));
-	description = gcm_calibrate_get_profile_description (GCM_CALIBRATE (calibrate_argyll));
-	model = gcm_calibrate_get_profile_model (GCM_CALIBRATE (calibrate_argyll));
-	manufacturer = gcm_calibrate_get_profile_manufacturer (GCM_CALIBRATE (calibrate_argyll));
-
 	/* get correct name of the command */
 	command = gcm_calibrate_argyll_get_tool_filename ("colprof", error);
 	if (command == NULL) {
@@ -915,6 +917,37 @@ gcm_calibrate_argyll_reference_kind_to_filename (GcmCalibrateReferenceKind kind)
 	return NULL;
 }
 
+/**
+ * gcm_utils_mkdir_and_copy:
+ **/
+static gboolean
+gcm_utils_mkdir_and_copy (GFile *source, GFile *destination, GError **error)
+{
+	gboolean ret;
+	GFile *parent;
+
+	g_return_val_if_fail (source != NULL, FALSE);
+	g_return_val_if_fail (destination != NULL, FALSE);
+
+	/* get parent */
+	parent = g_file_get_parent (destination);
+
+	/* create directory */
+	if (!g_file_query_exists (parent, NULL)) {
+		ret = g_file_make_directory_with_parents (parent, NULL, error);
+		if (!ret)
+			goto out;
+	}
+
+	/* do the copy */
+	ret = g_file_copy (source, destination, G_FILE_COPY_OVERWRITE, NULL, NULL, NULL, error);
+	if (!ret)
+		goto out;
+out:
+	g_object_unref (parent);
+	return ret;
+}
+
 /**
  * gcm_calibrate_argyll_device_copy:
  **/
@@ -1113,15 +1146,13 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 	/* get shared data */
 	g_object_get (calibrate_argyll,
 		      "basename", &basename,
+		      "copyright", &copyright,
+		      "description", &description,
+		      "model", &model,
+		      "manufacturer", &manufacturer,
 		      "reference-kind", &reference_kind,
 		      NULL);
 
-	/* get profile text data */
-	copyright = gcm_calibrate_get_profile_copyright (GCM_CALIBRATE (calibrate_argyll));
-	description = gcm_calibrate_get_profile_description (GCM_CALIBRATE (calibrate_argyll));
-	model = gcm_calibrate_get_profile_model (GCM_CALIBRATE (calibrate_argyll));
-	manufacturer = gcm_calibrate_get_profile_manufacturer (GCM_CALIBRATE (calibrate_argyll));
-
 	/* get correct name of the command */
 	command = gcm_calibrate_argyll_get_tool_filename ("colprof", error);
 	if (command == NULL) {
@@ -1368,108 +1399,6 @@ out:
 	return ret;
 }
 
-/**
- * gcm_calibrate_argyll_spotread_read_chart:
- **/
-static gboolean
-gcm_calibrate_argyll_spotread_read_chart (GcmCalibrateArgyll *calibrate_argyll, GError **error)
-{
-	gboolean ret = TRUE;
-	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
-	gchar *command = NULL;
-	gchar **argv = NULL;
-	GPtrArray *array = NULL;
-
-	/* get correct name of the command */
-	command = gcm_calibrate_argyll_get_tool_filename ("spotread", error);
-	if (command == NULL) {
-		ret = FALSE;
-		goto out;
-	}
-
-	/* TRANSLATORS: title, setting up the photospectromiter */
-	gcm_calibrate_set_title (GCM_CALIBRATE (calibrate_argyll),
-				 _("Setting up device"));
-	/* TRANSLATORS: dialog message */
-	gcm_calibrate_set_message (GCM_CALIBRATE (calibrate_argyll),
-				   _("Setting up the device to read a spot color…"));
-
-	/* reset flag so we exit after the single spotread */
-	priv->done_spot_read = FALSE;
-
-	/* argument array */
-	array = g_ptr_array_new_with_free_func (g_free);
-
-	/* setup the command */
-#ifdef FIXED_ARGYLL
-	g_ptr_array_add (array, g_strdup (command));
-#endif
-	g_ptr_array_add (array, g_strdup ("-v"));
-	if (priv->done_calibrate)
-		g_ptr_array_add (array, g_strdup ("-N"));
-	argv = gcm_utils_ptr_array_to_strv (array);
-	gcm_calibrate_argyll_debug_argv (command, argv);
-
-	/* start up the command */
-	ret = gcm_calibrate_argyll_fork_command (calibrate_argyll, argv, error);
-	if (!ret)
-		goto out;
-
-	/* wait until finished */
-	g_main_loop_run (priv->loop);
-
-	/* get result */
-	if (priv->response == GTK_RESPONSE_CANCEL) {
-		g_set_error_literal (error,
-				     GCM_CALIBRATE_ERROR,
-				     GCM_CALIBRATE_ERROR_USER_ABORT,
-				     "calibration was cancelled");
-		ret = FALSE;
-		goto out;
-	}
-#ifdef HAVE_VTE
-	if (priv->response == GTK_RESPONSE_REJECT) {
-		gchar *vte_text;
-		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
-		g_set_error (error,
-			     GCM_CALIBRATE_ERROR,
-			     GCM_CALIBRATE_ERROR_INTERNAL,
-			     "command failed to run successfully: %s", vte_text);
-		g_free (vte_text);
-		ret = FALSE;
-		goto out;
-	}
-#endif
-out:
-	if (array != NULL)
-		g_ptr_array_unref (array);
-	g_free (command);
-	g_strfreev (argv);
-	return ret;
-}
-
-/**
- * gcm_calibrate_argyll_spotread:
- **/
-static gboolean
-gcm_calibrate_argyll_spotread (GcmCalibrate *calibrate, CdDevice *device, CdSensor *sensor, GtkWindow *window, GError **error)
-{
-	GcmCalibrateArgyll *calibrate_argyll = GCM_CALIBRATE_ARGYLL(calibrate);
-	gboolean ret;
-
-	/* step 3 */
-	ret = gcm_calibrate_argyll_spotread_read_chart (calibrate_argyll, error);
-	if (!ret)
-		goto out;
-
-	/* step 5 */
-	ret = gcm_calibrate_argyll_remove_temp_files (calibrate_argyll, error);
-	if (!ret)
-		goto out;
-out:
-	return ret;
-}
-
 /**
  * gcm_calibrate_argyll_interaction:
  **/
@@ -2704,7 +2633,6 @@ gcm_calibrate_argyll_class_init (GcmCalibrateArgyllClass *klass)
 	parent_class->calibrate_display = gcm_calibrate_argyll_display;
 	parent_class->calibrate_device = gcm_calibrate_argyll_device;
 	parent_class->calibrate_printer = gcm_calibrate_argyll_printer;
-	parent_class->calibrate_spotread = gcm_calibrate_argyll_spotread;
 	parent_class->interaction = gcm_calibrate_argyll_interaction;
 
 	g_type_class_add_private (klass, sizeof (GcmCalibrateArgyllPrivate));
