@@ -61,6 +61,7 @@ typedef struct {
 	GtkWidget	*preview_widget_output;
 	guint		 example_index;
 	gchar		*profile_id;
+	gchar		*filename;
 	guint		 xid;
 	GtkListStore	*liststore_nc;
 	GtkListStore	*liststore_metadata;
@@ -96,14 +97,6 @@ enum {
 	GCM_PROFILES_COLUMN_LAST
 };
 
-enum {
-	GCM_VIEWER_COMBO_COLUMN_TEXT,
-	GCM_VIEWER_COMBO_COLUMN_PROFILE,
-	GCM_VIEWER_COMBO_COLUMN_TYPE,
-	GCM_VIEWER_COMBO_COLUMN_SORTABLE,
-	GCM_VIEWER_COMBO_COLUMN_LAST
-};
-
 #define GCM_VIEWER_TREEVIEW_WIDTH		350 /* px */
 #define GCM_VIEWER_MAX_EXAMPLE_IMAGES		4
 
@@ -257,7 +250,6 @@ gcm_viewer_update_profile_list (GcmViewerPrivate *viewer)
 
 		profile_kind = cd_profile_get_kind (profile);
 		icon_name = gcm_viewer_profile_kind_to_icon_name (profile_kind);
-		gtk_list_store_append (viewer->list_store_profiles, &iter);
 		filename = cd_profile_get_filename (profile);
 		if (filename == NULL)
 			continue;
@@ -266,6 +258,7 @@ gcm_viewer_update_profile_list (GcmViewerPrivate *viewer)
 					gcm_viewer_profile_get_sort_string (profile_kind),
 					description);
 		g_debug ("add %s to profiles list", filename);
+		gtk_list_store_append (viewer->list_store_profiles, &iter);
 		gtk_list_store_set (viewer->list_store_profiles, &iter,
 				    GCM_PROFILES_COLUMN_ID, filename,
 				    GCM_PROFILES_COLUMN_SORT, sort,
@@ -404,29 +397,25 @@ gcm_viewer_file_chooser_get_icc_profile (GcmViewerPrivate *viewer)
 static gboolean
 gcm_viewer_profile_import_file (GcmViewerPrivate *viewer, GFile *file)
 {
-	gboolean ret;
+	gboolean ret = FALSE;
 	GError *error = NULL;
-	GFile *destination = NULL;
+	CdProfile *profile_tmp = NULL;
 
-	/* check if correct type */
-	ret = gcm_utils_is_icc_profile (file);
-	if (!ret) {
-		g_debug ("not a ICC profile");
-		goto out;
-	}
-
-	/* copy icc file to ~/.color/icc */
-	destination = gcm_utils_get_profile_destination (file);
-	ret = gcm_utils_mkdir_and_copy (file, destination, &error);
-	if (!ret) {
+	/* copy icc file to users profile path */
+	profile_tmp = cd_client_import_profile_sync (viewer->client,
+						     file, NULL, &error);
+	if (profile_tmp == NULL) {
 		/* TRANSLATORS: could not read file */
 		gcm_viewer_error_dialog (viewer, _("Failed to copy file"), error->message);
 		g_error_free (error);
 		goto out;
 	}
+
+	/* success */
+	ret = TRUE;
 out:
-	if (destination != NULL)
-		g_object_unref (destination);
+	if (profile_tmp != NULL)
+		g_object_unref (profile_tmp);
 	return ret;
 }
 
@@ -785,7 +774,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 {
 	GtkWidget *widget;
 	GFile *file;
-	GcmProfile *gcm_profile;
+	GcmProfile *gcm_profile = NULL;
 	GcmClut *clut_trc = NULL;
 	GcmClut *clut_vcgt = NULL;
 	const gchar *profile_copyright;
@@ -806,6 +795,16 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	guint temperature;
 	guint filesize;
 	gboolean show_section = FALSE;
+	GError *error = NULL;
+
+	/* connect to the profile */
+	ret = cd_profile_connect_sync (profile, NULL, &error);
+	if (!ret) {
+		g_warning ("failed to connect to profile: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
 
 	gcm_profile = gcm_profile_new ();
 	file = g_file_new_for_path (cd_profile_get_filename (profile));
@@ -1044,6 +1043,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_from_srgb"));
 	gtk_widget_set_visible (widget, show_section);
 
+out:
 	if (gcm_profile != NULL)
 		g_object_unref (gcm_profile);
 	if (clut_trc != NULL)
@@ -1234,6 +1234,96 @@ gcm_viewer_named_color_treeview_clicked (GtkTreeSelection *selection, GcmViewerP
 	g_debug ("named color changed");
 }
 
+/**
+ * gcm_viewer_show_single_profile_by_filename:
+ **/
+static void
+gcm_viewer_show_single_profile_by_filename (GcmViewerPrivate *viewer,
+					    const gchar *filename)
+{
+	CdProfile *profile;
+	gboolean ret;
+	gchar *checksum = NULL;
+	gchar *data = NULL;
+	GError *error = NULL;
+	GHashTable *properties = NULL;
+	gsize len;
+
+	/* compute checksum */
+	ret = g_file_get_contents (viewer->filename,
+				   &data, &len, &error);
+	if (!ret) {
+		g_warning ("failed to read file %s: %s",
+			   viewer->filename,
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	checksum = g_compute_checksum_for_data (G_CHECKSUM_MD5,
+						(const guchar *) data,
+						len);
+
+
+
+	properties = g_hash_table_new_full (g_str_hash, g_str_equal,
+					    NULL, NULL);
+	g_hash_table_insert (properties,
+			     (gpointer) CD_PROFILE_PROPERTY_FILENAME,
+			     viewer->filename);
+	g_hash_table_insert (properties,
+			     (gpointer) CD_PROFILE_METADATA_FILE_CHECKSUM,
+			     checksum);
+
+	/* create a temp profile */
+	profile = cd_client_create_profile_sync (viewer->client,
+						 checksum,
+						 CD_OBJECT_SCOPE_TEMP,
+						 properties,
+						 NULL,
+						 &error);
+	if (profile == NULL) {
+		g_warning ("failed to create profile %s: %s",
+			   viewer->filename,
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	gcm_viewer_set_profile (viewer, profile);
+out:
+	g_free (data);
+	g_free (checksum);
+	if (properties != NULL)
+		g_hash_table_unref (properties);
+}
+
+/**
+ * gcm_viewer_show_single_profile_by_id:
+ **/
+static void
+gcm_viewer_show_single_profile_by_id (GcmViewerPrivate *viewer,
+				      const gchar *id)
+{
+	CdProfile *profile;
+	GError *error = NULL;
+
+	/* select a specific profile only */
+	profile = cd_client_find_profile_sync (viewer->client,
+					       id,
+					       NULL,
+					       &error);
+	if (profile == NULL) {
+		g_warning ("failed to get profile %s: %s",
+			   viewer->profile_id,
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	gcm_viewer_set_profile (viewer, profile);
+out:
+	if (profile != NULL)
+		g_object_unref (profile);
+}
+
 /**
  * gcm_viewer_startup_cb:
  **/
@@ -1297,7 +1387,8 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (widget));
 
 	/* hide the profiles pane */
-	if (viewer->profile_id != NULL) {
+	if (viewer->profile_id != NULL ||
+	    viewer->filename != NULL) {
 		widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder,
 				     "vbox_profiles"));
 		gtk_widget_hide (widget);
@@ -1471,25 +1562,22 @@ gcm_viewer_startup_cb (GApplication *application, GcmViewerPrivate *viewer)
 		gcm_window_set_parent_xid (GTK_WINDOW (main_window), viewer->xid);
 	}
 
-	/* do all this after the window has been set up */
-	if (viewer->profile_id == NULL) {
-		g_idle_add ((GSourceFunc) gcm_viewer_startup_phase1_idle_cb, viewer);
+	/* specified an ID */
+	if (viewer->profile_id != NULL) {
+		gcm_viewer_show_single_profile_by_id (viewer,
+						      viewer->profile_id);
 		goto out;
 	}
 
-	/* select a specific profile only */
-	profile = cd_client_find_profile_sync (viewer->client,
-					       viewer->profile_id,
-					       NULL,
-					       &error);
-	if (profile == NULL) {
-		g_warning ("failed to get profile %s: %s",
-			   viewer->profile_id,
-			   error->message);
-		g_error_free (error);
+	/* specified a filename */
+	if (viewer->filename != NULL) {
+		gcm_viewer_show_single_profile_by_filename (viewer,
+							    viewer->filename);
 		goto out;
 	}
-	gcm_viewer_set_profile (viewer, profile);
+
+	/* do all this after the window has been set up */
+	g_idle_add ((GSourceFunc) gcm_viewer_startup_phase1_idle_cb, viewer);
 out:
 	if (profile != NULL)
 		g_object_unref (profile);
@@ -1503,10 +1591,13 @@ int
 main (int argc, char **argv)
 {
 	gchar *profile_id = NULL;
+	gchar *filename = NULL;
 	GcmViewerPrivate *viewer;
 	GOptionContext *context;
 	guint xid;
 	int status = 0;
+	gboolean ret;
+	GError *error = NULL;
 
 	const GOptionEntry options[] = {
 		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
@@ -1515,6 +1606,9 @@ main (int argc, char **argv)
 		{ "profile", 'f', 0, G_OPTION_ARG_STRING, &profile_id,
 		  /* TRANSLATORS: show just the one profile, rather than all */
 		  _("Set the specific profile to show"), NULL },
+		{ "file", '\0', 0, G_OPTION_ARG_STRING, &filename,
+		  /* TRANSLATORS: show just the one filename, rather than all */
+		  _("Set the specific file to show"), NULL },
 		{ NULL}
 	};
 
@@ -1533,12 +1627,17 @@ main (int argc, char **argv)
 	g_option_context_add_main_entries (context, options, NULL);
 	g_option_context_add_group (context, gcm_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	g_option_context_parse (context, &argc, &argv, NULL);
+	ret = g_option_context_parse (context, &argc, &argv, &error);
+	if (!ret) {
+		g_warning ("failed to parse options: %s", error->message);
+		g_error_free (error);
+	}
 	g_option_context_free (context);
 
 	viewer = g_new0 (GcmViewerPrivate, 1);
 	viewer->xid = xid;
 	viewer->profile_id = profile_id;
+	viewer->filename = filename;
 
 	/* ensure single instance */
 	viewer->application = gtk_application_new ("org.gnome.ColorManager.Viewer", 0);
@@ -1555,8 +1654,8 @@ main (int argc, char **argv)
 		g_object_unref (viewer->builder);
 	if (viewer->client != NULL)
 		g_object_unref (viewer->client);
-	if (viewer->profile_id != NULL)
-		g_free (viewer->profile_id);
+	g_free (viewer->profile_id);
+	g_free (viewer->filename);
 	g_free (viewer);
 	return status;
 }
